# -*- coding: utf-8 -*-
"""pgsuite.connection module

Handling remote database connection

Example usage:

    >>> conn_string = 'dbname=geoserver_2 password=iverson port=6437 host=80.240.128.99 user=pav'
    >>> session = pg_remote_proxy('psycopg2', conn_string)


"""

__author__ = "Papavassileiou Vassilis"

__version__ = "0.1"

__revision__ = "0.1.0"

__date__ = "26-08-2014"

__copyright__ = "Copyright (c) 2014-2015 Geotag Aeroview Ltd"

__license__ = "GNU General Public License (GPL), Version 3"

__all__ = ['pg_remote_proxy', ]

from pgsuite.errors import (BackendNotFoundError, PgConnectionException)


def pg_remote_proxy(backend, pg_conn_data):
    """A proxy for DBAPI2 Postgresql drivers connection.

        Args:
          - backend (str): Name of the python driver.
          - pg_conn_data (dict) : Postgresql connection string data.

        Returns:
          - A connection instance.

        Raises:
          - BackendNotFoundError  : If backend can't be loaded at runtime.
          - PgConnectionException : If connection fails.
    """

    if backend not in locals() or backend not in globals():
        try:
            backend = __import__(backend)
        except ImportError:
            raise BackendNotFoundError(backend)

    try:
        session = backend.connect(pg_conn_data)
    except:
        raise PgConnectionException('Connection Error')

    return session


if __name__ == '__main__':
    import doctest
    doctest.testmod()