# -*- coding: utf-8 -*-
"""core.exceptions module

Exceptions and Error Handling for pgsuite package modules
"""

__author__ = "Papavassileiou Vassilis"

__version__ = '0.1'

__revision__ = "0.1.0"

__date__ = "26-08-2014"

__copyright__ = "Copyright (c) 2014-2015 Geotag Aeroview Ltd"

__license__ = "GNU General Public License (GPL), Version 3"


class BackendNotFoundError(Exception):
    """Raises if Postgresql driver can't be loaded from runtime.

        Attributes:
            backend (str): The `string` name of the postgresql driver
    """

    def __init__(self, backend):
        self.backend = backend

    def __str__(self):
        return "Cannot load {} from runtime, Is it on sys.path?".format(
            self.backend
        )


class PgConnectionException(Exception):
    """Raises if a Postgresql connection fails
    """
    pass


class InvalidJSONError(Exception):
    """Raises if a Postgresql connection fails
    """
    pass


class InvalidParamsFormatException(Exception):
    """Raises if Postgresql function parameters collection
        is not type of list
    """

    pass


class RPCTypeError(Exception):
    """Raises if Postgresql RPC `type` is not valid]

        Attributes:
            rpc_types (list) : A list with the available RPC types
    """

    def __init__(self, rpc_types):
        self.rpc_types = rpc_types

    def __str__(self):
        return "RPC type must be in {}".format(self.rpc_types)