# -*- coding: utf-8 -*-
"""pgsuite.models module

Handling remote database connection

Example usage:

    >>>
    >>>


"""

__author__ = "Papavassileiou Vassilis"

__version__ = "0.1"

__revision__ = "0.1.0"

__date__ = "26-08-2014"

__copyright__ = "Copyright (c) 2014-2015 Geotag Aeroview Ltd"

__license__ = "GNU General Public License (GPL), Version 3"


import json
from pgsuite.errors import InvalidJSONError

__all__ = ['QueryModel', ]


class QueryModel(object):
    """Remote database query base model

    Wraps Postgresql row in python objects

    TODO: better serialization support
    """

    def __init__(self, **query_data):
        self.__dict__.update(query_data)

    @classmethod
    def from_json(cls, query_string):
        """Creates a new Query model instance from a JSON string

            Args:
                - query_sting (str) : JSON string with instance data

            Raises:
                - InvalidJSONError: if query_string isn't valid JSON
        """
        try:
            return cls(**json.loads(query_string))
        except ValueError:
            raise InvalidJSONError("Invalid JSON formatted string")

    @classmethod
    def fetch_many(cls, cur_data, cur_desc):
        """Returns a list of QueryModel instances from a postgresql cursor
        """
        return [cls(**dict(zip([col.name for col in cur_desc], row)))
                for row in cur_data]

    @staticmethod
    def many_to_dict(query_list):
        return [q.to_dict for q in query_list]

    @property
    def to_json(self):
        return json.dumps(self.__dict__)

    @property
    def to_dict(self):
        return self.__dict__


if __name__ == '__main__':
    import doctest
    doctest.testmod()